@@ -1,5 +1,5 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # #
-# phonR version 0.3-0
+# phonR version 0.3-1
 # Functions for phoneticians and phonologists using R
 # Daniel McCloy, drmccloy@uw.edu
 # LICENSED UNDER THE GNU GENERAL PUBLIC LICENSE v3.0: http://www.gnu.org/licenses/gpl.html
@@ -11,7 +11,7 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 
 # USAGE: source("phonR.r")
-# --or-- R CMD install phonR_0.3-0.tar.gz (from command line)
+# --or-- R CMD install phonR_0.3-1.tar.gz (from command line)
 # Then library(phonR)
 # Then call functions as needed
 
@@ -23,13 +23,13 @@ normalizeVowels <- function(method, f0=NULL, f1=NULL, f2=NULL, f3=NULL, vowel=NU
     warning('Missing values: at least one of the arguments (f0, f1, f2, or f3) must be supplied.')
   }
   if (!(m %in% c('bark','mel','log','erb','z','zscore','ztransform','lobanov','logmean','nearey1','nearey2','scentroid','s','wattfabricius'))) {
-    warning('Method must be one of: bark, mel, log, erb, z|zscore|ztransform|lobanov, logmean|nearey1, nearey2, s|scentroid|wattfabricius')
+    warning('Method must be one of: bark, mel, log, erb, z|zscore|ztransform|lobanov, logmean|nearey1, nearey2, s|scentroid|wattfabricius.')
   }
   if (!is.null(grouping.factor) & !(m %in% c('z','zscore','ztransform','lobanov','logmean','nearey1','nearey2','s','scentroid','wattfabricius'))) {
-    warning('Argument \"grouping.factor\" is ignored for normalization method \"',method,'.\"')
+    warning('Argument \'grouping.factor\' is ignored for normalization method \'',method,'\'.')
   }
   if (!is.null(vowel) & !(m %in% c('s','scentroid','wattfabricius'))) {
-    warning('Argument \"vowel\" is ignored for normalization method \"',method,'.\"')
+    warning('Argument \'vowel\' is ignored for normalization method \'',method,'\'.')
   }
   if ((!is.null(f3) | !is.null(f0)) & !(m %in% c('s','scentroid','wattfabricius'))) {
     warning('f0 and F3 values ignored for s-centroid normalization method. Only F1 and F2 values returned.')
@@ -108,34 +108,48 @@ normalizeVowels <- function(method, f0=NULL, f1=NULL, f2=NULL, f3=NULL, vowel=NU
 }
 
 # VOWEL PLOTTING FUNCTION
-plotVowels <- function(vowel, f1, f2, f3=NULL, f0=NULL, grouping.factor=NULL, data=NULL, norm.method='none', match.unit=TRUE, match.axes='absolute', points='text', means='text', points.alpha=0.5, means.alpha=1, points.cex=0.6, means.cex=1.2, ignore.hidden=TRUE, ellipses=TRUE, ellipse.alpha=0.3173, polygon=TRUE, poly.order=NULL, poly.include=NULL, single.plot=TRUE, axis.col='#666666FF', titles='auto', axis.titles='auto', font.size=12, font.family='', grayscale=FALSE, vary.shapes=grayscale, vary.lines=grayscale, uniform.style=!single.plot, legend=single.plot, aspect.ratio=NULL, plot.dims=c(6.5,6.5), plot.unit='in', dpi=NULL, output='screen') {
+plotVowels <- function(data=NULL, vowel=NULL, f1=NULL, f2=NULL, f3=NULL, f0=NULL, grouping.factor=NULL, norm.method='none', match.unit=TRUE, match.axes='absolute', points='text', means='text', points.alpha=0.5, means.alpha=1, points.cex=0.6, means.cex=1.2, ignore.hidden=TRUE, ellipses=TRUE, ellipse.alpha=0.3173, polygon=TRUE, poly.order=NULL, poly.include=NULL, single.plot=TRUE, titles='auto', axis.titles='auto', axis.cex=0.8, garnish.col='#666666FF', grayscale=FALSE, vary.colors=!grayscale, vary.shapes=grayscale, vary.lines=grayscale, legend=single.plot, output='screen', family='', pointsize=12, units='in', width=6.5, height=6.5, res=72, asp=NULL) {
 	# MAKE CASE-INSENSITIVE
 	norm.method <- tolower(norm.method)
 	match.axes <- tolower(match.axes)
 	output <- tolower(output)
 	points <- tolower(points)
 	means <- tolower(means)
+	# SOME DEFAULTS
+	if (!is.null(data)) {
+		if (is.null(vowel)) vowel <- 'vowel'
+		if (is.null(f1)) f1 <- 'f1'
+		if (is.null(f2)) f2 <- 'f2'
+	} else {
+		if (is.null(vowel)) vowel <- vowel
+		if (is.null(f1)) f1 <- f1
+		if (is.null(f2)) f2 <- f2
+	}
 	# OUTPUT TYPES
-	if (output=='jpeg') {output <- 'jpg'}
-	if (output=='tiff') {output <- 'tif'}
+	if (output=='jpeg') output <- 'jpg'
+	if (output=='tiff') output <- 'tif'
 	if (output %in% c('pdf','svg','screen')) {
-		if (plot.unit=='cm') {
-			plot.dims <- plot.dims/2.54
-		} else if (plot.unit=='mm') {
-			plot.dims <- plot.dims/2540
-		} else if (plot.unit=='px') {
-			plot.dims <- plot.dims/72
+		if (units=='cm') {
+			width <- width/2.54
+			height <- height/2.54
+		} else if (units=='mm') {
+			width <- width/2540
+			height <- height/2540
+		} else if (units=='px') {
+			width <- width/72
+			height <- height/72
 		}
-#		if (!is.null(dpi)) {
-#			warning('Argument \'dpi\' ignored for output formats \'pdf\', \'svg\', and \'screen\'')
-#		}
-	} else if (is.null(dpi)) { # output type is raster
-		warning('No resolution specified, using default (72dpi).')
-		dpi <- 72
-#	} else {
-#		warning('Generating raster graphics can be very slow, especially at high DPI settings or if single.plot=FALSE. Be patient if R appears to have frozen.')
 	}
 	# CHECK FOR BOGUS ARGUMENTS, ETC
+	if (legend %in% c('top','topright','right','bottomright','bottom','bottomleft','left','topleft','center')) {
+		legend.pos <- legend
+		legend <- TRUE
+	} else if (!(legend %in% c(1,0))) {
+		warning('Unknown argument value \'', legend, '\': \'legend\' must be logical, or a character vector specifying location (e.g., \'top\', \'bottomright\', \'center\', etc).')
+		legend <- single.plot
+	} else {
+		legend.pos <- 'bottomleft'
+	}
 	if (single.plot & match.axes != 'absolute') {
 		match.axes <- 'absolute'
 		warning('When \'single.plot\'=TRUE, \'match.axes\' is coerced to \'absolute\'.')
@@ -144,9 +158,9 @@ plotVowels <- function(vowel, f1, f2, f3=NULL, f0=NULL, grouping.factor=NULL, da
 		warning('Unknown argument value \'', match.axes, '\': \'match.axes\' must be one of \'absolute\', \'relative\', or \'none\'. Using default (\'absolute\').')
 		match.axes <- 'absolute'
 	}
-	if (!(plot.unit %in% c('in','cm','mm','px'))) {
-	  warning('Unknown argument value \'', plot.unit, '\': \'plot.unit\' must be one of \'in\', \'cm\', \'mm\', or \'px\'. Using default (\'in\').')
-	  plot.unit <- 'in'
+	if (!(units %in% c('in','cm','mm','px'))) {
+	  warning('Unknown argument value \'', units, '\': \'units\' must be one of \'in\', \'cm\', \'mm\', or \'px\'. Using default (\'in\').')
+	  units <- 'in'
 	}
 	if (!(output %in% c('pdf','svg','jpg','tif','png','bmp','screen'))) {
 		warning('Unknown argument value \'', output, '\': \'output\' must be one of \'pdf\', \'svg\', \'png\', \'tif\', \'bmp\', \'jpg\', or \'screen\'. Using default (\'screen\').')
@@ -164,20 +178,24 @@ plotVowels <- function(vowel, f1, f2, f3=NULL, f0=NULL, grouping.factor=NULL, da
 		warning('Ellipse size is measured as an alpha level, and must be within [0,1]. Using default (0.3173).')
 		ellipse.alpha <- 0.3173
 	}
-	if (!is.null(aspect.ratio)) {
-		if (!is.numeric(aspect.ratio) | aspect.ratio <= 0) {
+	if (!is.null(asp)) {
+		if (!is.numeric(asp) | asp <= 0) {
 			warning('Aspect ratio (horizontal/vertical) must be a positive number. Using default (\'NULL\', which adapts aspect ratio to maximize plot area usage).')
-			aspect.ratio <- NULL
+			asp <- NULL
 		}
 	}
 	if (!match.unit & norm.method %in% c('s','scentroid','wattfabricius')) {
 		warning('Argument \'match.unit\' coerced to TRUE with norm.method \'s-centroid\': plotting Hz on axes is uninformative for linear transforms.')
 		match.unit <- TRUE
 	}
-	# FONT HANDLING FOR WINDOWS
-	if (.Platform$OS.type == 'windows' & output %in% c('png','jpg','bmp','tif','screen')) {
-		windowsFonts(phonR=windowsFont(font.family))
-		font.family <- 'phonR'
+	# FONT HANDLING FOR WINDOWS (RELATED BLOCK AT END OF SCRIPT)
+	if (.Platform$OS.type=='windows' & family!='' & output %in% c('png','jpg','bmp','tif','screen')) {
+		oldFont <- windowsFonts()$sans
+		windowsFonts(sans=windowsFont(family))
+		family <- 'sans'
+		if (output=='screen') {
+			warning('FYI, font specification may fail if saving as PDF from onscreen plot window menu. To ensure PDF font fidelity, run plotVowels() with output=\'pdf\'.')
+		}
 	}
 	# DATA PREPROCESSING
 	group <- NULL
@@ -186,8 +204,8 @@ plotVowels <- function(vowel, f1, f2, f3=NULL, f0=NULL, grouping.factor=NULL, da
 		f1 <- data[,match(eval(f1),colnames(data))]
 		f2 <- data[,match(eval(f2),colnames(data))]
 		vowel <- data[,match(eval(vowel),colnames(data))]
-		if (!is.null(f3)) { f3 <- data[,match(eval(f3),colnames(data))] }
-		if (!is.null(f0)) { f0 <- data[,match(eval(f0),colnames(data))] }
+		if (!is.null(f3)) f3 <- data[,match(eval(f3),colnames(data))]
+		if (!is.null(f0)) f0 <- data[,match(eval(f0),colnames(data))]
 		if (!is.null(grouping.factor)) {
 			group <- data[,match(eval(grouping.factor),colnames(data))]
 			group <- factor(group)
@@ -196,7 +214,7 @@ plotVowels <- function(vowel, f1, f2, f3=NULL, f0=NULL, grouping.factor=NULL, da
 		}
 	} else {
 	  if (!is.null(grouping.factor)) {
-  	  group <- factor(grouping.factor)
+  	    group <- factor(grouping.factor)
 	  } else {
 	    group <- rep('noGroupsDefined',length(f1))
 	  }
@@ -230,7 +248,7 @@ plotVowels <- function(vowel, f1, f2, f3=NULL, f0=NULL, grouping.factor=NULL, da
 	# COMPENSATE FOR MISMATCHES BETWEEN DEFAULT/PROVIDED LEVELS, AND LEVELS ACTUALLY PRESENT IN THE DATA
 	if (is.null(poly.include)) {
 		poly.include <- length(poly.order)
-	} else if(poly.include>length(poly.order)) {
+	} else if (poly.include>length(poly.order)) {
 		poly.include <- length(poly.order)
 	}
 	# SAVE FOR LATER, SINCE THE MAIN f1 AND f2 COLUMNS MAY GET NORMALIZED
@@ -465,61 +483,56 @@ plotVowels <- function(vowel, f1, f2, f3=NULL, f0=NULL, grouping.factor=NULL, da
 	pointcolors <- rep(hcl(0,0,0,points.alpha), length=length(glist)) # default color: (semitransparent) black
 	linetypes <- rep(1, length=length(glist)) # default linetype: solid
 	symbols <- rep(16, length=length(glist)) # default symbol: filled circle
-	if (!uniform.style) {
-		if (vary.shapes) {
-			symbols <- rep(c(0:2,5,15:18,3,4,6), length=length(glist)) # open{square,circle,triangle,diamond}, filled{square,circle,triangle,diamond}, plus, x, inverted triangle
-		}
-		if (vary.lines) {
-      linetypes <- rep(c('solid', '43', '23258385', '13', 'F3131313', '93', '28282383', '23F3', '232923', '4313', 'F3'), length=length(glist))
-		}
-		if (length(glist)>1) {
-		  if (!grayscale) {
-			  vowelcolors <- hcl(h=seq(0,360-(360/length(glist)),length=length(glist)), c=100, l=35, alpha=means.alpha, fixup=TRUE)
-			  pointcolors <- hcl(h=seq(0,360-(360/length(glist)),length=length(glist)), c=100, l=35, alpha=points.alpha, fixup=TRUE)
-#		  } else {
-#			  vowelcolors <- rep(hcl(0,0,0,means.alpha), length=length(glist))
-#			  pointcolors <- rep(hcl(0,0,0,points.alpha), length=length(glist))
-		  }
+	if (vary.shapes) {
+		symbols <- rep(c(16,1,17,2,15,0,18,5,3,4,6), length=length(glist)) # filled/open{circle,triangle,square,diamond}, plus, x, inverted triangle
+	}
+	if (vary.lines) {
+		linetypes <- rep(c('solid', '43', '23258385', '23', 'F3131313', '93', '28282383', '23F3', '232923', '4313', 'F3'), length=length(glist))
+	}
+	if (vary.colors) {
+		if (grayscale) {
+			vals <- seq(0,80,length=length(glist)+1)
+			vals <- vals[-length(vals)]
+			vowelcolors <- hcl(h=0, c=0, l=vals, alpha=means.alpha, fixup=TRUE)
+			pointcolors <- hcl(h=0, c=0, l=vals, alpha=points.alpha, fixup=TRUE)
+		} else {
+			vowelcolors <- hcl(h=seq(0,360-(360/length(glist)),length=length(glist)), c=100, l=35, alpha=means.alpha, fixup=TRUE)
+			pointcolors <- hcl(h=seq(0,360-(360/length(glist)),length=length(glist)), c=100, l=35, alpha=points.alpha, fixup=TRUE)
 		}
 	}
 	# IF PLOTTING ALL GROUPS ON ONE GRAPH, INITIALIZE OUTPUT DEVICE ONLY ONCE (BEFORE THE 'FOR' LOOP)
 	if (single.plot) {
-	  if (output=='screen') {
-#    	if (.Platform$OS.type == 'windows') {
-#  		  windows(width=plot.dims[1], height=plot.dims[2], family=font.family, pointsize=font.size)
-#		  } else {
-#  		  x11(width=plot.dims[1], height=plot.dims[2], family=font.family, pointsize=font.size)
-#		  }
-  		op <- par(mfrow=c(1,1), mar=c(1,0.5,topmargin,4.5), mgp=c(0,0.3,0), oma=c(0,0,0,0), family=font.family, ps=font.size)
-	  } else {
-		  # PDF
-		  if (output=='pdf') {
-			  cairo_pdf(filename=paste('vowels_by_',grouping.factor,'.pdf',sep=''), width=plot.dims[1], height=plot.dims[2], pointsize=font.size, family=font.family)
-		  # SVG
-		  } else if (output=='svg') {
-			  svg(filename=paste('vowels_by_',grouping.factor,'.svg',sep=''), width=plot.dims[1], height=plot.dims[2], pointsize=font.size, family=font.family)
-		  # JPG
-		  } else if (output=='jpg') {
-			  jpeg(filename=paste('vowels_by_',grouping.factor,'.jpg',sep=''), units=plot.unit, width=plot.dims[1], height=plot.dims[2], res=dpi, family=font.family, pointsize=font.size, quality=100)
-		  # TIF
-		  } else if (output=='tif') {
-			  tiff(filename=paste('vowels_by_',grouping.factor,'.tif',sep=''), units=plot.unit, width=plot.dims[1], height=plot.dims[2], res=dpi, family=font.family, pointsize=font.size, compression='lzw')
-		  # PNG
-		  } else if (output=='png') {
-			  png(filename=paste('vowels_by_',grouping.factor,'.png',sep=''), units=plot.unit, width=plot.dims[1], height=plot.dims[2], res=dpi, family=font.family, pointsize=font.size)
-		  # BMP
-		  } else if (output=='bmp') {
-			  bmp(filename=paste('vowels_by_',grouping.factor,'.bmp',sep=''), units=plot.unit, width=plot.dims[1], height=plot.dims[2], res=dpi, family=font.family, pointsize=font.size)
-		  }
-		  par(mfrow=c(1,1), mar=c(1,0.5,topmargin,4.5), mgp=c(0,0.3,0), oma=c(0,0,0,0))
-	  }
+		if (output=='screen') {
+			op <- par(mfrow=c(1,1), mar=c(1,0.5,topmargin,4.5), mgp=c(0,0.3,0), oma=c(0,0,0,0), family=family, ps=pointsize)
+		} else {
+			# PDF
+			if (output=='pdf') {
+				cairo_pdf(filename=paste('vowels_by_',grouping.factor,'.pdf',sep=''), width=width, height=height, pointsize=pointsize, family=family)
+			# SVG
+			} else if (output=='svg') {
+				svg(filename=paste('vowels_by_',grouping.factor,'.svg',sep=''), width=width, height=height, pointsize=pointsize, family=family)
+			# JPG
+			} else if (output=='jpg') {
+				jpeg(filename=paste('vowels_by_',grouping.factor,'.jpg',sep=''), units=units, width=width, height=height, res=res, family=family, pointsize=pointsize, quality=100)
+			# TIF
+			} else if (output=='tif') {
+				tiff(filename=paste('vowels_by_',grouping.factor,'.tif',sep=''), units=units, width=width, height=height, res=res, family=family, pointsize=pointsize, compression='lzw')
+			# PNG
+			} else if (output=='png') {
+				png(filename=paste('vowels_by_',grouping.factor,'.png',sep=''), units=units, width=width, height=height, res=res, family=family, pointsize=pointsize)
+			# BMP
+			} else if (output=='bmp') {
+				bmp(filename=paste('vowels_by_',grouping.factor,'.bmp',sep=''), units=units, width=width, height=height, res=res, family=family, pointsize=pointsize)
+			}
+			par(mfrow=c(1,1), mar=c(1,0.5,topmargin,4.5), mgp=c(0,0.3,0), oma=c(0,0,0,0))
+		}
 	} else if (output=='screen') { # single.plot==FALSE
-	  # SET UP FOR LATTICE PLOTTING
-	  num.rows <- num.cols <- ceiling(sqrt(length(glist)))
-	  if(length(glist) <= num.rows*(num.rows-1)) {
-		  num.rows <- num.rows-1
-	  }
-  }
+		# SET UP FOR LATTICE PLOTTING
+		num.rows <- num.cols <- ceiling(sqrt(length(glist)))
+		if(length(glist) <= num.rows*(num.rows-1)) {
+			num.rows <- num.rows-1
+		}
+	}
   
 	# PLOT!
 	for (i in 1:length(glist)) {
@@ -533,22 +546,22 @@ plotVowels <- function(vowel, f1, f2, f3=NULL, f0=NULL, grouping.factor=NULL, da
 		if (!single.plot & output!='screen') {
 		  # PDF
 		  if (output=='pdf') {
-			  cairo_pdf(filename=paste(curGroup,'.pdf',sep=''), width=plot.dims[1], height=plot.dims[2], pointsize=font.size, family=font.family)
+			  cairo_pdf(filename=paste(curGroup,'.pdf',sep=''), width=width, height=height, pointsize=pointsize, family=family)
 		  # SVG
 		  } else if (output=='svg') {
-			  svg(filename=paste(curGroup,'.svg',sep=''), width=plot.dims[1], height=plot.dims[2], pointsize=font.size, family=font.family)
+			  svg(filename=paste(curGroup,'.svg',sep=''), width=width, height=height, pointsize=pointsize, family=family)
 		  # JPG
 		  } else if (output=='jpg') {
-			  jpeg(filename=paste(curGroup,'.jpg',sep=''), units=plot.unit, width=plot.dims[1], height=plot.dims[2], res=dpi, family=font.family, pointsize=font.size, quality=100)
+			  jpeg(filename=paste(curGroup,'.jpg',sep=''), units=units, width=width, height=height, res=res, family=family, pointsize=pointsize, quality=100)
 		  # TIF
 		  } else if (output=='tif') {
-			  tiff(filename=paste(curGroup,'.tif',sep=''), units=plot.unit, width=plot.dims[1], height=plot.dims[2], res=dpi, family=font.family, pointsize=font.size, compression='lzw')
+			  tiff(filename=paste(curGroup,'.tif',sep=''), units=units, width=width, height=height, res=res, family=family, pointsize=pointsize, compression='lzw')
 		  # PNG
 		  } else if (output=='png') {
-			  png(filename=paste(curGroup,'.png',sep=''), units=plot.unit, width=plot.dims[1], height=plot.dims[2], res=dpi, family=font.family, pointsize=font.size)
+			  png(filename=paste(curGroup,'.png',sep=''), units=units, width=width, height=height, res=res, family=family, pointsize=pointsize)
 		  # BMP
 		  } else if (output=='bmp') {
-			  bmp(filename=paste(curGroup,'.bmp',sep=''), units=plot.unit, width=plot.dims[1], height=plot.dims[2], res=dpi, family=font.family, pointsize=font.size)
+			  bmp(filename=paste(curGroup,'.bmp',sep=''), units=units, width=width, height=height, res=res, family=family, pointsize=pointsize)
 		  }
 		  par(mfrow=c(1,1), mar=c(1,0.5,topmargin,4.5), mgp=c(0,0.3,0), oma=c(0,0,0,0))
 		}
@@ -597,14 +610,14 @@ plotVowels <- function(vowel, f1, f2, f3=NULL, f0=NULL, grouping.factor=NULL, da
 		# DRAW AXES & MARGIN TEXT, UNLESS OVERPLOTTING AND WE'RE ALREADY PAST THE FIRST GROUP
 		if (!single.plot & output=='screen' & i==1) {
 		  # INITIALIZE ONSCREEN LATTICE LAYOUT
-		  op <- par(mfrow=c(num.rows,num.cols), mar=c(1,0.5,topmargin,4.5), mgp=c(0,0.3,0), oma=c(0,0,0,0), family=font.family, ps=font.size)
+		  op <- par(mfrow=c(num.rows,num.cols), mar=c(1,0.5,topmargin,4.5), mgp=c(0,0.3,0), oma=c(0,0,0,0), family=family, ps=pointsize)
 	  }
 		if (!single.plot | i==1) {
 			# INITIALIZE EMPTY PLOT
-			plot(0, 0, xlim=xlims, ylim=ylims, type='n', axes=FALSE, ann=FALSE, frame.plot=FALSE, asp=aspect.ratio)
+			plot(0, 0, xlim=xlims, ylim=ylims, type='n', axes=FALSE, ann=FALSE, frame.plot=FALSE, asp=asp)
 			# AXES
-			axis(3, at=xticks, labels=xtext, las=0, col=axis.col, col.ticks=axis.col, col.axis=axis.col, cex.axis=0.8, tck=-.005)
-			axis(4, at=yticks, labels=ytext, las=2, col=axis.col, col.ticks=axis.col, col.axis=axis.col, cex.axis=0.8, tck=-.005)
+			axis(3, at=xticks, labels=xtext, las=0, col=garnish.col, col.ticks=garnish.col, col.axis=garnish.col, cex.axis=axis.cex, tck=-.005)
+			axis(4, at=yticks, labels=ytext, las=2, col=garnish.col, col.ticks=garnish.col, col.axis=garnish.col, cex.axis=axis.cex, tck=-.005)
 			# TITLE
 			if (is.null(data)) {
 			  title.factor <- as.character(quote(grouping.factor))
@@ -636,8 +649,8 @@ plotVowels <- function(vowel, f1, f2, f3=NULL, f0=NULL, grouping.factor=NULL, da
 			  hlabel <- paste('F2 (',unit,')',sep='')
 			  vlabel <- paste('F1 (',unit,')',sep='')
 			}
-			mtext(hlabel, side=3, cex=0.8, las=1, line=1.5, font=2, col=axis.col)
-			mtext(vlabel, side=4, cex=0.8, las=3, line=2.5, font=2, col=axis.col)
+			mtext(hlabel, side=3, cex=0.8, las=1, line=1.5, font=2, col=garnish.col)
+			mtext(vlabel, side=4, cex=0.8, las=3, line=2.5, font=2, col=garnish.col)
 		# REUSE THE SAME PLOT
 		} else if (single.plot) {
 			par(new=TRUE)
@@ -676,34 +689,26 @@ plotVowels <- function(vowel, f1, f2, f3=NULL, f0=NULL, grouping.factor=NULL, da
     # PLOT LEGEND
 		if (legend & (!single.plot | i==length(glist))) {
 			if (points=='shape' | means=='shape') {
-	      if (ellipses | polygon) { # lines, symbols
-		      legend('bottomleft', legend=glist, fill=NA, border=NA, col=vowelcolors, lty=linetypes, pch=symbols, bty='n', inset=0.05, seg.len=3.5) # cex, lwd=1, border='n', text.font=1
-	      } else { # symbols only
-		      legend('bottomleft', legend=glist, fill=NA, border=NA, col=vowelcolors, pch=symbols, bty='n', inset=0.05) # cex, lwd=1, border='n', text.font=1
-	      }
+				if (ellipses | polygon) { # lines, symbols
+					legend(legend.pos, legend=glist, fill=NA, border=NA, col=vowelcolors, lty=linetypes, pch=symbols, bty='n', inset=0.05, seg.len=3.5) # cex, lwd=1, border='n', text.font=1
+				} else { # symbols only
+					legend(legend.pos, legend=glist, fill=NA, border=NA, col=vowelcolors, pch=symbols, bty='n', inset=0.05) # cex, lwd=1, border='n', text.font=1
+				}
 			} else {
-			  if (ellipses | polygon) { # lines only
-		      legend('bottomleft', legend=glist, fill=NA, border=NA, col=vowelcolors, lty=linetypes, bty='n', inset=0.05, seg.len=3.5) # cex, lwd=1, border='n', text.font=1
-			  } else { # boxes only
-        	legend('bottomleft', legend=glist, fill=vowelcolors, border=NA, bty='n', inset=0.05) # cex, lwd=1, border='n', text.font=1
-			  }
+				if (ellipses | polygon) { # lines only
+					legend(legend.pos, legend=glist, fill=NA, border=NA, col=vowelcolors, lty=linetypes, bty='n', inset=0.05, seg.len=3.5) # cex, lwd=1, border='n', text.font=1
+				} else { # boxes only
+					legend(legend.pos, legend=glist, fill=vowelcolors, border=NA, bty='n', inset=0.05) # cex, lwd=1, border='n', text.font=1
+				}
 			}
 		}
 		# CLOSE THE OUTPUT DEVICE FOR EACH INDIVIDUAL GROUP PLOT (UNLESS OUTPUT = SCREEN)
-		if (!single.plot) {
-			if (output != 'screen') {
-				dev.off()
-			}
-		}
+		if (!single.plot & output!='screen') dev.off()
 	} # for(i in 1:length(groups))
 	# CLOSE THE OUTPUT DEVICE FOR SINGLE OVERPLOTTED GRAPH (UNLESS OUTPUT = SCREEN)
-	if (single.plot) {
-		if (output != 'screen') {
-			dev.off()
-		}
-	}
-  # RESET ORIGINAL GRAPHING PARAMETERS
-	if (output == 'screen') {
-    par(op)
-	}
+	if (single.plot & output!='screen') dev.off()
+	# RESET ORIGINAL GRAPHING PARAMETERS
+	if (output == 'screen') par(op)
+	# FONT HANDLING FOR WINDOWS
+	if (.Platform$OS.type=='windows' & family!='' & output %in% c('png','jpg','bmp','tif','screen')) windowsFonts(sans=oldFont)
 } #plotVowels <- function(...)
